==> types_boto3_pinpoint_email-1.35.71-py3-none-any.whl: types_boto3_pinpoint_email/paginator.py <==
"""
Type annotations for pinpoint-email service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_pinpoint_email.client import PinpointEmailClient
    from types_boto3_pinpoint_email.paginator import (
        GetDedicatedIpsPaginator,
        ListConfigurationSetsPaginator,
        ListDedicatedIpPoolsPaginator,
        ListDeliverabilityTestReportsPaginator,
        ListEmailIdentitiesPaginator,
    )

    session = Session()
    client: PinpointEmailClient = session.client("pinpoint-email")

    get_dedicated_ips_paginator: GetDedicatedIpsPaginator = client.get_paginator("get_dedicated_ips")
    list_configuration_sets_paginator: ListConfigurationSetsPaginator = client.get_paginator("list_configuration_sets")
    list_dedicated_ip_pools_paginator: ListDedicatedIpPoolsPaginator = client.get_paginator("list_dedicated_ip_pools")
    list_deliverability_test_reports_paginator: ListDeliverabilityTestReportsPaginator = client.get_paginator("list_deliverability_test_reports")
    list_email_identities_paginator: ListEmailIdentitiesPaginator = client.get_paginator("list_email_identities")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    GetDedicatedIpsRequestGetDedicatedIpsPaginateTypeDef,
    GetDedicatedIpsResponseTypeDef,
    ListConfigurationSetsRequestListConfigurationSetsPaginateTypeDef,
    ListConfigurationSetsResponseTypeDef,
    ListDedicatedIpPoolsRequestListDedicatedIpPoolsPaginateTypeDef,
    ListDedicatedIpPoolsResponseTypeDef,
    ListDeliverabilityTestReportsRequestListDeliverabilityTestReportsPaginateTypeDef,
    ListDeliverabilityTestReportsResponseTypeDef,
    ListEmailIdentitiesRequestListEmailIdentitiesPaginateTypeDef,
    ListEmailIdentitiesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "GetDedicatedIpsPaginator",
    "ListConfigurationSetsPaginator",
    "ListDedicatedIpPoolsPaginator",
    "ListDeliverabilityTestReportsPaginator",
    "ListEmailIdentitiesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class GetDedicatedIpsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/GetDedicatedIps.html#PinpointEmail.Paginator.GetDedicatedIps)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#getdedicatedipspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[GetDedicatedIpsRequestGetDedicatedIpsPaginateTypeDef]
    ) -> _PageIterator[GetDedicatedIpsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/GetDedicatedIps.html#PinpointEmail.Paginator.GetDedicatedIps.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#getdedicatedipspaginator)
        """


class ListConfigurationSetsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListConfigurationSets.html#PinpointEmail.Paginator.ListConfigurationSets)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listconfigurationsetspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListConfigurationSetsRequestListConfigurationSetsPaginateTypeDef]
    ) -> _PageIterator[ListConfigurationSetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListConfigurationSets.html#PinpointEmail.Paginator.ListConfigurationSets.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listconfigurationsetspaginator)
        """


class ListDedicatedIpPoolsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDedicatedIpPools.html#PinpointEmail.Paginator.ListDedicatedIpPools)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdedicatedippoolspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDedicatedIpPoolsRequestListDedicatedIpPoolsPaginateTypeDef]
    ) -> _PageIterator[ListDedicatedIpPoolsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDedicatedIpPools.html#PinpointEmail.Paginator.ListDedicatedIpPools.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdedicatedippoolspaginator)
        """


class ListDeliverabilityTestReportsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDeliverabilityTestReports.html#PinpointEmail.Paginator.ListDeliverabilityTestReports)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdeliverabilitytestreportspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListDeliverabilityTestReportsRequestListDeliverabilityTestReportsPaginateTypeDef
        ],
    ) -> _PageIterator[ListDeliverabilityTestReportsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDeliverabilityTestReports.html#PinpointEmail.Paginator.ListDeliverabilityTestReports.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdeliverabilitytestreportspaginator)
        """


class ListEmailIdentitiesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListEmailIdentities.html#PinpointEmail.Paginator.ListEmailIdentities)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listemailidentitiespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListEmailIdentitiesRequestListEmailIdentitiesPaginateTypeDef]
    ) -> _PageIterator[ListEmailIdentitiesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListEmailIdentities.html#PinpointEmail.Paginator.ListEmailIdentities.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listemailidentitiespaginator)
        """

==> types_boto3_pinpoint_email-1.35.93-py3-none-any.whl: types_boto3_pinpoint_email/paginator.py <==
"""
Type annotations for pinpoint-email service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_pinpoint_email.client import PinpointEmailClient
    from types_boto3_pinpoint_email.paginator import (
        GetDedicatedIpsPaginator,
        ListConfigurationSetsPaginator,
        ListDedicatedIpPoolsPaginator,
        ListDeliverabilityTestReportsPaginator,
        ListEmailIdentitiesPaginator,
    )

    session = Session()
    client: PinpointEmailClient = session.client("pinpoint-email")

    get_dedicated_ips_paginator: GetDedicatedIpsPaginator = client.get_paginator("get_dedicated_ips")
    list_configuration_sets_paginator: ListConfigurationSetsPaginator = client.get_paginator("list_configuration_sets")
    list_dedicated_ip_pools_paginator: ListDedicatedIpPoolsPaginator = client.get_paginator("list_dedicated_ip_pools")
    list_deliverability_test_reports_paginator: ListDeliverabilityTestReportsPaginator = client.get_paginator("list_deliverability_test_reports")
    list_email_identities_paginator: ListEmailIdentitiesPaginator = client.get_paginator("list_email_identities")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    GetDedicatedIpsRequestPaginateTypeDef,
    GetDedicatedIpsResponseTypeDef,
    ListConfigurationSetsRequestPaginateTypeDef,
    ListConfigurationSetsResponseTypeDef,
    ListDedicatedIpPoolsRequestPaginateTypeDef,
    ListDedicatedIpPoolsResponseTypeDef,
    ListDeliverabilityTestReportsRequestPaginateTypeDef,
    ListDeliverabilityTestReportsResponseTypeDef,
    ListEmailIdentitiesRequestPaginateTypeDef,
    ListEmailIdentitiesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "GetDedicatedIpsPaginator",
    "ListConfigurationSetsPaginator",
    "ListDedicatedIpPoolsPaginator",
    "ListDeliverabilityTestReportsPaginator",
    "ListEmailIdentitiesPaginator",
)


if TYPE_CHECKING:
    _GetDedicatedIpsPaginatorBase = Paginator[GetDedicatedIpsResponseTypeDef]
else:
    _GetDedicatedIpsPaginatorBase = Paginator  # type: ignore[assignment]


class GetDedicatedIpsPaginator(_GetDedicatedIpsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/GetDedicatedIps.html#PinpointEmail.Paginator.GetDedicatedIps)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#getdedicatedipspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[GetDedicatedIpsRequestPaginateTypeDef]
    ) -> PageIterator[GetDedicatedIpsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/GetDedicatedIps.html#PinpointEmail.Paginator.GetDedicatedIps.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#getdedicatedipspaginator)
        """


if TYPE_CHECKING:
    _ListConfigurationSetsPaginatorBase = Paginator[ListConfigurationSetsResponseTypeDef]
else:
    _ListConfigurationSetsPaginatorBase = Paginator  # type: ignore[assignment]


class ListConfigurationSetsPaginator(_ListConfigurationSetsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListConfigurationSets.html#PinpointEmail.Paginator.ListConfigurationSets)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listconfigurationsetspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListConfigurationSetsRequestPaginateTypeDef]
    ) -> PageIterator[ListConfigurationSetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListConfigurationSets.html#PinpointEmail.Paginator.ListConfigurationSets.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listconfigurationsetspaginator)
        """


if TYPE_CHECKING:
    _ListDedicatedIpPoolsPaginatorBase = Paginator[ListDedicatedIpPoolsResponseTypeDef]
else:
    _ListDedicatedIpPoolsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDedicatedIpPoolsPaginator(_ListDedicatedIpPoolsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDedicatedIpPools.html#PinpointEmail.Paginator.ListDedicatedIpPools)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdedicatedippoolspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDedicatedIpPoolsRequestPaginateTypeDef]
    ) -> PageIterator[ListDedicatedIpPoolsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDedicatedIpPools.html#PinpointEmail.Paginator.ListDedicatedIpPools.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdedicatedippoolspaginator)
        """


if TYPE_CHECKING:
    _ListDeliverabilityTestReportsPaginatorBase = Paginator[
        ListDeliverabilityTestReportsResponseTypeDef
    ]
else:
    _ListDeliverabilityTestReportsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDeliverabilityTestReportsPaginator(_ListDeliverabilityTestReportsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDeliverabilityTestReports.html#PinpointEmail.Paginator.ListDeliverabilityTestReports)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdeliverabilitytestreportspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDeliverabilityTestReportsRequestPaginateTypeDef]
    ) -> PageIterator[ListDeliverabilityTestReportsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListDeliverabilityTestReports.html#PinpointEmail.Paginator.ListDeliverabilityTestReports.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listdeliverabilitytestreportspaginator)
        """


if TYPE_CHECKING:
    _ListEmailIdentitiesPaginatorBase = Paginator[ListEmailIdentitiesResponseTypeDef]
else:
    _ListEmailIdentitiesPaginatorBase = Paginator  # type: ignore[assignment]


class ListEmailIdentitiesPaginator(_ListEmailIdentitiesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListEmailIdentities.html#PinpointEmail.Paginator.ListEmailIdentities)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listemailidentitiespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListEmailIdentitiesRequestPaginateTypeDef]
    ) -> PageIterator[ListEmailIdentitiesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email/paginator/ListEmailIdentities.html#PinpointEmail.Paginator.ListEmailIdentities.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pinpoint_email/paginators/#listemailidentitiespaginator)
        """
